JBoss Tools SVN: r16012 - trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/publishers.
by jbosstools-commits@lists.jboss.org
Author: rob.stryker(a)jboss.com
Date: 2009-06-17 09:14:09 -0400 (Wed, 17 Jun 2009)
New Revision: 16012
Modified:
trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/publishers/JstPublisher.java
Log:
Issue Tracker: 303042
Modified: trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/publishers/JstPublisher.java
===================================================================
--- trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/publishers/JstPublisher.java 2009-06-17 12:31:47 UTC (rev 16011)
+++ trunk/as/plugins/org.jboss.ide.eclipse.as.core/jbosscore/org/jboss/ide/eclipse/as/core/publishers/JstPublisher.java 2009-06-17 13:14:09 UTC (rev 16012)
@@ -279,7 +279,8 @@
}
finally{
try{
- packager.finished();
+ if( packager != null )
+ packager.finished();
}
catch(IOException e){
IStatus status = new Status(IStatus.ERROR, JBossServerCorePlugin.PLUGIN_ID, IEventCodes.JST_PUB_ASSEMBLE_FAIL,
15 years, 6 months
JBoss Tools SVN: r16011 - in trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe: editor/mozilla and 1 other directories.
by jbosstools-commits@lists.jboss.org
Author: yradtsevich
Date: 2009-06-17 08:31:47 -0400 (Wed, 17 Jun 2009)
New Revision: 16011
Modified:
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeEditorPart.java
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaPreview.java
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/VpeUIMessages.java
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/messages.properties
Log:
https://jira.jboss.org/jira/browse/JBIDE-4256
- org.eclipse.ui.internal.part.StatusPart has been used to show the VPE exceptions
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeEditorPart.java
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeEditorPart.java 2009-06-17 12:29:35 UTC (rev 16010)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeEditorPart.java 2009-06-17 12:31:47 UTC (rev 16011)
@@ -83,7 +83,6 @@
import org.jboss.tools.vpe.editor.mozilla.EditorLoadWindowListener;
import org.jboss.tools.vpe.editor.mozilla.MozillaEditor;
import org.jboss.tools.vpe.editor.mozilla.MozillaPreview;
-import org.jboss.tools.vpe.editor.util.Constants;
import org.jboss.tools.vpe.editor.xpl.CustomSashForm;
import org.jboss.tools.vpe.editor.xpl.EditorSettings;
import org.jboss.tools.vpe.editor.xpl.SashSetting;
@@ -860,21 +859,19 @@
} catch (PartInitException e) {
VpePlugin.reportProblem(e);
}
- if (visualEditor != null) {
- visualEditor.setEditorLoadWindowListener(new EditorLoadWindowListener() {
- public void load() {
- visualEditor.setEditorLoadWindowListener(null);
- visualEditor.setController(new VpeController(
- VpeEditorPart.this));
- selectionBar.setVpeController(visualEditor.getController());
- visualEditor.getController().setSelectionBarController(selectionBar);
- createShowSelectionBarMenuItem();
- visualEditor.getController().init(sourceEditor, visualEditor);
- }
+ visualEditor.setEditorLoadWindowListener(new EditorLoadWindowListener() {
+ public void load() {
+ visualEditor.setEditorLoadWindowListener(null);
+ visualEditor.setController(new VpeController(
+ VpeEditorPart.this));
+ selectionBar.setVpeController(visualEditor.getController());
+ visualEditor.getController().setSelectionBarController(selectionBar);
+ createShowSelectionBarMenuItem();
+ visualEditor.getController().init(sourceEditor, visualEditor);
+ }
- });
- visualEditor.createPartControl(visualContent);
- }
+ });
+ visualEditor.createPartControl(visualContent);
}
/**
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaPreview.java 2009-06-17 12:29:35 UTC (rev 16010)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaPreview.java 2009-06-17 12:31:47 UTC (rev 16011)
@@ -24,7 +24,6 @@
import org.jboss.tools.vpe.editor.context.VpePageContext;
import org.jboss.tools.vpe.editor.mapping.VpeDomMapping;
import org.jboss.tools.vpe.editor.template.VpeTemplateManager;
-import org.jboss.tools.vpe.xulrunner.XulRunnerException;
import org.jboss.tools.vpe.xulrunner.editor.XulRunnerEditor;
/**
@@ -79,7 +78,7 @@
});
setInitialContent();
getXulRunnerEditor().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
- } catch (XulRunnerException e) {
+ } catch (Throwable e) {
showXulRunnerException(parent, e);
}
}
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/VpeUIMessages.java
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/VpeUIMessages.java 2009-06-17 12:29:35 UTC (rev 16010)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/VpeUIMessages.java 2009-06-17 12:31:47 UTC (rev 16011)
@@ -31,7 +31,6 @@
public static String PAGE_DESIGN_OPTIONS;
public static String HIDE_SELECTION_BAR;
public static String SHOW_SELECTION_BAR;
- public static String MOZILLA_LOADING_ERROR_LOG_ENTRY;
public static String MOZILLA_LOADING_ERROR;
public static String MOZILLA_LOADING_ERROR_LINK_TEXT;
public static String MOZILLA_LOADING_ERROR_LINK;
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/messages.properties
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/messages.properties 2009-06-17 12:29:35 UTC (rev 16010)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/messages/messages.properties 2009-06-17 12:31:47 UTC (rev 16011)
@@ -8,10 +8,8 @@
PAGE_DESIGN_OPTIONS=Page Design Options
HIDE_SELECTION_BAR=Hide Selection Bar
SHOW_SELECTION_BAR=Show Selection Bar
-MOZILLA_LOADING_ERROR_LOG_ENTRY=Cannot run the Visual Page Editor
-MOZILLA_LOADING_ERROR=Cannot run the Visual Page Editor. See the Error Log view for the stack trace of the error.\n\
- Probably your system environment needs to be slightly changed.
-MOZILLA_LOADING_ERROR_LINK_TEXT=Find out more.
+MOZILLA_LOADING_ERROR=Could not open the Visual Page Editor: {0}
+MOZILLA_LOADING_ERROR_LINK_TEXT=See JBoss Tools Visual Editor FAQ
# START NON-TRANSLATABLE
MOZILLA_LOADING_ERROR_LINK=http://www.jboss.org/community/docs/DOC-10862
# END NON-TRANSLATABLE
15 years, 6 months
JBoss Tools SVN: r16010 - in trunk: tests/tests/org.jboss.tools.test/src/org/jboss/tools/tests and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: akazakov
Date: 2009-06-17 08:29:35 -0400 (Wed, 17 Jun 2009)
New Revision: 16010
Modified:
trunk/seam/tests/org.jboss.tools.seam.core.test/src/org/jboss/tools/seam/core/test/SeamValidatorsTest.java
trunk/tests/tests/org.jboss.tools.test/src/org/jboss/tools/tests/AbstractResourceMarkerTest.java
Log:
Fixed Seam Core Tests
Modified: trunk/seam/tests/org.jboss.tools.seam.core.test/src/org/jboss/tools/seam/core/test/SeamValidatorsTest.java
===================================================================
--- trunk/seam/tests/org.jboss.tools.seam.core.test/src/org/jboss/tools/seam/core/test/SeamValidatorsTest.java 2009-06-17 12:18:53 UTC (rev 16009)
+++ trunk/seam/tests/org.jboss.tools.seam.core.test/src/org/jboss/tools/seam/core/test/SeamValidatorsTest.java 2009-06-17 12:29:35 UTC (rev 16010)
@@ -192,7 +192,7 @@
messages = getMarkersMessage(statefulComponentFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker 'Stateful component does not contain @Remove method' not found", "Stateful component \"statefulComponent\" must have a method marked @Remove", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(statefulComponentFile);
+ lineNumbers = getMarkersNumbersOfLine(statefulComponentFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 16, lineNumbers[0].intValue());
@@ -215,7 +215,7 @@
messages = getMarkersMessage(statefulComponentFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker 'Stateful component does not contain @Destroy method' not found", "Stateful component \"statefulComponent\" must have a method marked @Destroy", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(statefulComponentFile);
+ lineNumbers = getMarkersNumbersOfLine(statefulComponentFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 16, lineNumbers[0].intValue());
@@ -238,7 +238,7 @@
messages = getMarkersMessage(statefulComponentFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker 'Stateful component has wrong scope' not found", "Stateful component \"statefulComponent\" should not have org.jboss.seam.ScopeType.PAGE, nor org.jboss.seam.ScopeType.STATELESS", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(statefulComponentFile);
+ lineNumbers = getMarkersNumbersOfLine(statefulComponentFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 16, lineNumbers[0].intValue());
@@ -262,7 +262,7 @@
messages = getMarkersMessage(componentsFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker 'Component class name cannot be resolved to a type' was not found", "\"org.domain.SeamWebWarTestProject.session.StateComponent\" cannot be resolved to a type", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(componentsFile);
+ lineNumbers = getMarkersNumbersOfLine(componentsFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 15, lineNumbers[0].intValue());
@@ -295,7 +295,7 @@
messages = getMarkersMessage(componentsFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker 'Component class does not have a setter or a field for the property' not found", "Class \"StatefulComponent\" of component \"statefulComponent\" does not have a setter or a field for the property \"abc\"", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(componentsFile);
+ lineNumbers = getMarkersNumbersOfLine(componentsFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 16, lineNumbers[0].intValue());
@@ -577,7 +577,7 @@
messages = getMarkersMessage(selectionIndexTestFile, SEAM_MARKER_FILTER);
assertTrue("Problem marker 'Multiple data binder", messages[0].startsWith("@DataModelSelection and @DataModelSelectionIndex without name of the DataModel requires the only one @DataModel in the component"));
- lineNumbers = getMarkersNumbersOfLine(selectionIndexTestFile);
+ lineNumbers = getMarkersNumbersOfLine(selectionIndexTestFile, SEAM_MARKER_FILTER);
assertTrue("Wrong number of problem markers", lineNumbers.length == messages.length && messages.length == 2);
@@ -611,7 +611,7 @@
messages = getMarkersMessage(selectionTestFile, SEAM_MARKER_FILTER);
assertTrue("Problem marker 'Unknown @DataModel/@Out name", messages[0].startsWith("Unknown @DataModel/@Out name: \"messageList2\""));
- lineNumbers = getMarkersNumbersOfLine(selectionTestFile);
+ lineNumbers = getMarkersNumbersOfLine(selectionTestFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 27, lineNumbers[0].intValue());
@@ -621,7 +621,7 @@
messages = getMarkersMessage(selectionIndexTestFile, SEAM_MARKER_FILTER);
assertTrue("Problem marker 'Unknown @DataModel/@Out name", messages[0].startsWith("Unknown @DataModel/@Out name: \"messageList2\""));
- lineNumbers = getMarkersNumbersOfLine(selectionIndexTestFile);
+ lineNumbers = getMarkersNumbersOfLine(selectionIndexTestFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 27, lineNumbers[0].intValue());
}
@@ -683,7 +683,7 @@
assertEquals("Problem marker 'Unknown variable name' not found", "Unknown context variable name: \"messageList5\"", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(contextVariableTestFile);
+ lineNumbers = getMarkersNumbersOfLine(contextVariableTestFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 22, lineNumbers[0].intValue());
@@ -751,7 +751,7 @@
assertEquals("Problem marker 'Property cannot be resolved' was not found", "\"actionType2\" cannot be resolved", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(abcComponentXHTMLFile);
+ lineNumbers = getMarkersNumbersOfLine(abcComponentXHTMLFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 22, lineNumbers[0].intValue());
@@ -788,7 +788,7 @@
assertEquals("Problem marker 'Unpaired Getter/Setter' was not found", "Property \"actionType\" has only Setter. Getter is missing.", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(abcComponentXHTMLFile);
+ lineNumbers = getMarkersNumbersOfLine(abcComponentXHTMLFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 22, lineNumbers[0].intValue());
@@ -809,7 +809,7 @@
assertEquals("Problem marker 'Unpaired Getter/Setter' was not found", "Property \"actionType\" has only Getter. Setter is missing.", messages[0]);
- lineNumbers = getMarkersNumbersOfLine(abcComponentXHTMLFile);
+ lineNumbers = getMarkersNumbersOfLine(abcComponentXHTMLFile, SEAM_MARKER_FILTER);
assertEquals("Problem marker has wrong line number", 22, lineNumbers[0].intValue());
}
@@ -848,7 +848,7 @@
assertEquals("There should be the only one error marker in DuplicateComponent.java.", 1, lineNumbers.length);
assertEquals("Problem marker has wrong line number", 5, lineNumbers[0].intValue());
- lineNumbers = getMarkersNumbersOfLine(componentsXmlFile);
+ lineNumbers = getMarkersNumbersOfLine(componentsXmlFile, SEAM_MARKER_FILTER);
assertEquals("There should be two error marker in components.xml.", 2, lineNumbers.length);
assertTrue("Problem marker was not found on 8 line", findLine(lineNumbers, 8));
assertTrue("Problem marker was not found on 9 line", findLine(lineNumbers, 9));
Modified: trunk/tests/tests/org.jboss.tools.test/src/org/jboss/tools/tests/AbstractResourceMarkerTest.java
===================================================================
--- trunk/tests/tests/org.jboss.tools.test/src/org/jboss/tools/tests/AbstractResourceMarkerTest.java 2009-06-17 12:18:53 UTC (rev 16009)
+++ trunk/tests/tests/org.jboss.tools.test/src/org/jboss/tools/tests/AbstractResourceMarkerTest.java 2009-06-17 12:29:35 UTC (rev 16010)
@@ -131,21 +131,20 @@
}
public static String[] getMarkersMessage(IResource resource, IMarkerFilter filter) {
- String[] messages = null;
+ List<String> messages = new ArrayList<String>();
try{
IMarker[] markers = resource.findMarkers(null, true, IResource.DEPTH_INFINITE);
- messages = new String[markers.length];
// System.out.println("Marker - "+markers[i].getAttribute(IMarker.MESSAGE, "")); //$NON-NLS-1$//$NON-NLS-2$
for(int i=0;i<markers.length;i++){
if(filter==null || filter.accept(markers[i])) {
- messages[i] = markers[i].getAttribute(IMarker.MESSAGE, ""); //$NON-NLS-1$
+ messages.add(markers[i].getAttribute(IMarker.MESSAGE, "")); //$NON-NLS-1$
}
}
}catch(CoreException ex){
JUnitUtils.fail("Can't get problem markers", ex); //$NON-NLS-1$
}
- return messages;
+ return messages.toArray(new String[0]);
}
public static Integer[] getMarkersNumbersOfLine(IResource resource) {
15 years, 6 months
JBoss Tools SVN: r16009 - trunk/seam/docs/reference/en/images/seam_editors.
by jbosstools-commits@lists.jboss.org
Author: chukhutsina
Date: 2009-06-17 08:18:53 -0400 (Wed, 17 Jun 2009)
New Revision: 16009
Added:
trunk/seam/docs/reference/en/images/seam_editors/seam_editors_2c.png
Log:
<html><head><meta name="qrichtext" content="1" /></head><body style="font-size:9pt;font-family:Sans Serif">
<p>https://jira.jboss.org/jira/browse/JBDS-768 -Added the description of OpenOn available in components.xml to open drools security files.</p>
</body></html>
Added: trunk/seam/docs/reference/en/images/seam_editors/seam_editors_2c.png
===================================================================
(Binary files differ)
Property changes on: trunk/seam/docs/reference/en/images/seam_editors/seam_editors_2c.png
___________________________________________________________________
Name: svn:mime-type
+ application/octet-stream
15 years, 6 months
JBoss Tools SVN: r16008 - trunk/seam/docs/reference/en/modules.
by jbosstools-commits@lists.jboss.org
Author: chukhutsina
Date: 2009-06-17 08:18:15 -0400 (Wed, 17 Jun 2009)
New Revision: 16008
Modified:
trunk/seam/docs/reference/en/modules/seam_editors.xml
Log:
<html><head><meta name="qrichtext" content="1" /></head><body style="font-size:9pt;font-family:Sans Serif">
<p>https://jira.jboss.org/jira/browse/JBDS-768 -Added the description of OpenOn available in components.xml to open drools security files.</p>
</body></html>
Modified: trunk/seam/docs/reference/en/modules/seam_editors.xml
===================================================================
--- trunk/seam/docs/reference/en/modules/seam_editors.xml 2009-06-17 11:43:04 UTC (rev 16007)
+++ trunk/seam/docs/reference/en/modules/seam_editors.xml 2009-06-17 12:18:15 UTC (rev 16008)
@@ -502,8 +502,20 @@
</imageobject>
</mediaobject>
</figure>
-
-<para>
+ <para>If you use Rule-based authorization with Drools in your Seam application you can apply OpenOn
+ in <emphasis>
+ <property>components.xml</property></emphasis> to open the files containing rule definitions in the <emphasis>
+ <property>"rule-files"</property></emphasis> tag.
+ </para>
+ <figure>
+ <title>OpenOn in components.xml file</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/seam_editors/seam_editors_2c.png"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+ <para>
OpenOn is also supported in seam components where <property> In annotation</property> is presented.
After pressing <property>Ctrl + left click</property> on the seam component specified in <code>@In </code> you will get the possibility to open the file where the component is declarated as well as
all of the seam components where it is used in the next declarations:</para>
15 years, 6 months
JBoss Tools SVN: r16007 - trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core.
by jbosstools-commits@lists.jboss.org
Author: scabanovich
Date: 2009-06-17 07:43:04 -0400 (Wed, 17 Jun 2009)
New Revision: 16007
Modified:
trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/SeamProject.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-4494
Modified: trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/SeamProject.java
===================================================================
--- trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/SeamProject.java 2009-06-17 11:23:50 UTC (rev 16006)
+++ trunk/seam/plugins/org.jboss.tools.seam.core/src/org/jboss/tools/seam/internal/core/SeamProject.java 2009-06-17 11:43:04 UTC (rev 16007)
@@ -812,7 +812,7 @@
SeamComponentDeclaration current = (SeamComponentDeclaration)currentComponents.remove(loaded.getId());
loaded.setSourcePath(source);
-
+
String name = getComponentName(loaded);
String oldName = getComponentName(current);
@@ -995,7 +995,7 @@
if(d == null) return null;
String name = d.getName();
- if(name == null || name.length() == 0 && d instanceof SeamXmlComponentDeclaration) {
+ if((name == null || name.length() == 0) && d instanceof SeamXmlComponentDeclaration) {
String className = getClassName(d);
if(className != null && className.length() > 0) {
SeamJavaComponentDeclaration jd = components.getJavaDeclaration(className);
15 years, 6 months
JBoss Tools SVN: r16006 - trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/propertieseditor.
by jbosstools-commits@lists.jboss.org
Author: scabanovich
Date: 2009-06-17 07:23:50 -0400 (Wed, 17 Jun 2009)
New Revision: 16006
Modified:
trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/propertieseditor/PropertiesEditor.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-4465
Modified: trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/propertieseditor/PropertiesEditor.java
===================================================================
--- trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/propertieseditor/PropertiesEditor.java 2009-06-17 08:20:32 UTC (rev 16005)
+++ trunk/common/plugins/org.jboss.tools.common.model.ui/src/org/jboss/tools/common/propertieseditor/PropertiesEditor.java 2009-06-17 11:23:50 UTC (rev 16006)
@@ -24,6 +24,7 @@
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.QualifiedName;
import org.eclipse.jface.action.IAction;
+import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.ITextOperationTarget;
import org.eclipse.jface.viewers.ISelection;
@@ -35,6 +36,7 @@
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
@@ -71,12 +73,18 @@
static final String ATTR_NAME = "name"; //$NON-NLS-1$
static final String ATTR_VALUE = "value"; //$NON-NLS-1$
static final String ATTR_ENABLED = "enabled"; //$NON-NLS-1$
+
XModelObject property = PreferenceModelUtilities.getPreferenceModel().createModelObject(ENT_PROPERTY, null);
- XAttributeSupport support = new XAttributeSupport(property, XEntityDataImpl.create(new String[][]{
+ XAttributeSupport nsupport = new XAttributeSupport(property, XEntityDataImpl.create(new String[][]{
{ENT_PROPERTY, "yes"}, //$NON-NLS-1$
{ATTR_NAME, "no"}, //$NON-NLS-1$
+ }), true);
+ XAttributeSupport vsupport = new XAttributeSupport(property, XEntityDataImpl.create(new String[][]{
+ {ENT_PROPERTY, "yes"}, //$NON-NLS-1$
{ATTR_VALUE, "no"} //$NON-NLS-1$
}));
+ Button fake = null;
+
private Label statistics;
Composite panel = null;
private ArrayList<String> actionMapping = new ArrayList<String>();
@@ -113,14 +121,19 @@
GridLayout layout = new GridLayout(1, false);
panel.setLayout(layout);
- support.getPropertyEditorAdapterByName(ATTR_NAME).setValue(pHelper.nameFilter);
- support.getPropertyEditorAdapterByName(ATTR_VALUE).setValue(pHelper.valueFilter);
+ nsupport.getPropertyEditorAdapterByName(ATTR_NAME).setValue(pHelper.nameFilter);
+ vsupport.getPropertyEditorAdapterByName(ATTR_VALUE).setValue(pHelper.valueFilter);
ExpandableComposite g = new ExpandableComposite(panel, SWT.NONE);
g.setText(UIMessages.PROPERTIES_EDITOR_FILTER);
g.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
Composite g1 = new Composite(g, SWT.NONE);
- g1.setLayout(new GridLayout(2, false));
+ GridLayout l1 = new GridLayout(3, false);
+ l1.horizontalSpacing = 10;
+ l1.marginRight = 0;
+ l1.marginHeight = 0;
+ l1.verticalSpacing = 0;
+ g1.setLayout(l1);
g1.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
g.setClient(g1);
g.setExpanded(filterOpened);
@@ -133,9 +146,31 @@
panel.layout();
}
});
- support.fillComposite(g1);
- support.addPropertyChangeListener(pHelper);
-
+
+ Composite ng = new Composite(g1, SWT.NONE);
+ GridLayout nl = new GridLayout(2, false);
+ nl.marginRight = 5;
+ nl.marginHeight = 0;
+ ng.setLayout(nl);
+ ng.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ nsupport.fillComposite(ng);
+ nsupport.addPropertyChangeListener(pHelper);
+
+ Composite vg = new Composite(g1, SWT.NONE);
+ GridLayout vl = new GridLayout(2, false);
+ vl.marginHeight = 0;
+ vg.setLayout(vl);
+ vg.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ vsupport.fillComposite(vg);
+ vsupport.addPropertyChangeListener(pHelper);
+
+ fake = new Button(g1, SWT.NONE);
+ fake.setText(ADD);
+ GridData fd = new GridData();
+ fd.widthHint = convertHorizontalDLUsToPixels(g1, IDialogConstants.BUTTON_WIDTH);
+ fake.setLayoutData(fd);
+ fake.setVisible(false);
+
statistics = new Label(panel, SWT.NONE);
statistics.setVisible(false);
GridData d = new GridData(GridData.FILL_HORIZONTAL);
15 years, 6 months
JBoss Tools SVN: r16005 - in trunk/bpel/plugins: org.eclipse.bpel.apache.ode.deploy.ui/META-INF and 3 other directories.
by jbosstools-commits@lists.jboss.org
Author: dennyxu
Date: 2009-06-17 04:20:32 -0400 (Wed, 17 Jun 2009)
New Revision: 16005
Modified:
trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/META-INF/MANIFEST.MF
trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/plugin.xml
trunk/bpel/plugins/org.eclipse.bpel.apache.ode.runtime/META-INF/MANIFEST.MF
trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/ModelQuery.java
trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/model/IConstants.java
Log:
https://engineering.redhat.com/trac/ODE/ticket/22
bpel validator consider xpath2.0 as being invalid
Modified: trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/META-INF/MANIFEST.MF
===================================================================
--- trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/META-INF/MANIFEST.MF 2009-06-17 07:55:00 UTC (rev 16004)
+++ trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/META-INF/MANIFEST.MF 2009-06-17 08:20:32 UTC (rev 16005)
@@ -15,7 +15,7 @@
org.eclipse.bpel.model;bundle-version="0.4.0",
org.eclipse.wst.wsdl;bundle-version="[1.1.200,2.0.0)",
org.eclipse.xsd;bundle-version="[2.4.0,3.0.0)",
- javax.wsdl;bundle-version="[1.4.0,1.5.0)",
+ javax.wsdl;bundle-version="1.4.0",
org.eclipse.core.databinding;bundle-version="[1.1.0,2.0.0)",
org.eclipse.jface.databinding;bundle-version="[1.2.0,2.0.0)",
org.eclipse.emf.edit.ui;bundle-version="[2.4.0,3.0.0)",
Modified: trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/plugin.xml
===================================================================
--- trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/plugin.xml 2009-06-17 07:55:00 UTC (rev 16004)
+++ trunk/bpel/plugins/org.eclipse.bpel.apache.ode.deploy.ui/plugin.xml 2009-06-17 08:20:32 UTC (rev 16005)
@@ -7,7 +7,7 @@
<editor
class="org.eclipse.bpel.apache.ode.deploy.ui.editors.ODEDeployMultiPageEditor"
contributorClass="org.eclipse.bpel.apache.ode.deploy.ui.editors.ODEDeployMultiPageEditorContributor"
- filenames="deploy.xml"
+ filenames="bpel-deploy.xml,deploy.xml"
icon="icons/obj16/ode.gif"
id="org.eclipse.bpel.apache.ode.deploy.ui.editors.ODEDeployMultiPageEditor"
name="ODE Deployment Descriptor Editor">
Modified: trunk/bpel/plugins/org.eclipse.bpel.apache.ode.runtime/META-INF/MANIFEST.MF
===================================================================
--- trunk/bpel/plugins/org.eclipse.bpel.apache.ode.runtime/META-INF/MANIFEST.MF 2009-06-17 07:55:00 UTC (rev 16004)
+++ trunk/bpel/plugins/org.eclipse.bpel.apache.ode.runtime/META-INF/MANIFEST.MF 2009-06-17 08:20:32 UTC (rev 16005)
@@ -23,7 +23,7 @@
org.eclipse.jst.server.ui;bundle-version="[1.0.303,2.0.0)",
org.eclipse.jst.common.project.facet.core;bundle-version="[1.3.0,2.0.0)",
org.eclipse.jst.server.core;bundle-version="[1.1.0,2.0.0)",
- javax.wsdl;bundle-version="[1.4.0,1.5.0)",
+ javax.wsdl;bundle-version="1.4.0",
org.eclipse.bpel.apache.ode.deploy.model;bundle-version="0.4.0"
Bundle-Activator: org.eclipse.bpel.apache.ode.runtime.OdePlugin
Export-Package: org.eclipse.bpel.apache.ode.runtime
Modified: trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/ModelQuery.java
===================================================================
--- trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/ModelQuery.java 2009-06-17 07:55:00 UTC (rev 16004)
+++ trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/ModelQuery.java 2009-06-17 08:20:32 UTC (rev 16005)
@@ -68,11 +68,13 @@
case SUPPORT_QUERY_LANGUAGE :
return
IConstants.XMLNS_XPATH_QUERY_LANGUAGE.equals ( value ) ||
+ IConstants.XMLNS_XPATH_QUERY_LANGUAGE_XPATH2.equals ( value ) ||
IConstants.XMLNS_XPATH_QUERY_LANGUAGE_2.equals( value );
case SUPPORT_EXPRESSION_LANGUAGE :
return
IConstants.XMLNS_XPATH_EXPRESSION_LANGUAGE.equals ( value ) ||
+ IConstants.XMLNS_XPATH_EXPRESSION_LANGUAGE_XPATH2.equals( value ) ||
IConstants.XMLNS_XPATH_EXPRESSION_LANGUAGE_2.equals( value );
case SUPPORT_IMPORT_TYPE :
Modified: trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/model/IConstants.java
===================================================================
--- trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/model/IConstants.java 2009-06-17 07:55:00 UTC (rev 16004)
+++ trunk/bpel/plugins/org.eclipse.bpel.validator/src/org/eclipse/bpel/validator/model/IConstants.java 2009-06-17 08:20:32 UTC (rev 16005)
@@ -59,12 +59,14 @@
/** The default expression language */
public static final String XMLNS_XPATH_EXPRESSION_LANGUAGE = "urn:oasis:names:tc:wsbpel:2.0:sublang:xpath1.0"; //$NON-NLS-1$
+ public static final String XMLNS_XPATH_EXPRESSION_LANGUAGE_XPATH2 = "urn:oasis:names:tc:wsbpel:2.0:sublang:xpath2.0"; //$NON-NLS-1$
/** A variant from previous spec iterations */
public static final String XMLNS_XPATH_EXPRESSION_LANGUAGE_2 = "http://www.w3.org/TR/1999/REC-xpath-19991116"; //$NON-NLS-1$
/** The default query language */
public static final String XMLNS_XPATH_QUERY_LANGUAGE = "urn:oasis:names:tc:wsbpel:2.0:sublang:xpath1.0";
+ public static final String XMLNS_XPATH_QUERY_LANGUAGE_XPATH2 = "urn:oasis:names:tc:wsbpel:2.0:sublang:xpath2.0";
public static final String XMLNS_XPATH_QUERY_LANGUAGE_2 = "http://www.w3.org/TR/1999/REC-xpath-19991116";
15 years, 6 months
JBoss Tools SVN: r16004 - trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide.
by jbosstools-commits@lists.jboss.org
Author: yradtsevich
Date: 2009-06-17 03:55:00 -0400 (Wed, 17 Jun 2009)
New Revision: 16004
Modified:
trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-3441
JUnit test adjusted: more time left to the visual refresh job to be completed.
Modified: trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java
===================================================================
--- trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java 2009-06-17 07:26:59 UTC (rev 16003)
+++ trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java 2009-06-17 07:55:00 UTC (rev 16004)
@@ -52,10 +52,10 @@
VpeController controller1 = openPageInVpe(TEST_PAGE_NAME_1);
VpeController controller2 = openPageInVpe(TEST_PAGE_NAME_2);
- for (int i = 0; i < 20; i++) {
+ for (int i = 0; i < 5; i++) {
controller1.visualRefresh();
controller2.visualRefresh();
- TestUtil.delay(500);
+ TestUtil.delay(5000);
TestUtil.waitForJobs();
checkTaggedDivValue(controller1);
checkTaggedDivValue(controller2);
15 years, 6 months
JBoss Tools SVN: r16003 - in trunk/ws/docs/reference/en: modules and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: Grid.Qian
Date: 2009-06-17 03:26:59 -0400 (Wed, 17 Jun 2009)
New Revision: 16003
Added:
trunk/ws/docs/reference/en/images/topdown/jbossws_facet_0.png
Modified:
trunk/ws/docs/reference/en/modules/topdown.xml
Log:
JBDS-673: JBoss WS User Guide: Explanation on How to get Project FAcets popup
Added: trunk/ws/docs/reference/en/images/topdown/jbossws_facet_0.png
===================================================================
(Binary files differ)
Property changes on: trunk/ws/docs/reference/en/images/topdown/jbossws_facet_0.png
___________________________________________________________________
Name: svn:mime-type
+ application/octet-stream
Modified: trunk/ws/docs/reference/en/modules/topdown.xml
===================================================================
--- trunk/ws/docs/reference/en/modules/topdown.xml 2009-06-17 07:24:51 UTC (rev 16002)
+++ trunk/ws/docs/reference/en/modules/topdown.xml 2009-06-17 07:26:59 UTC (rev 16003)
@@ -33,7 +33,7 @@
</listitem>
<listitem>
<para>Target runtime: any server depending on your installation. If it is not listed,
- click New and browse to the location where it is installed to. You may set <emphasis>
+ click <property>New</property> button and browse to the location where it is installed to. You may set <emphasis>
<property>Target Runtime</property>
</emphasis> to <emphasis>
<property>None</property></emphasis>, in this case, you should add <link linkend="addfacet">JBoss Web Service
@@ -48,6 +48,10 @@
</figure>
</listitem>
<listitem>
+ <para>Configuration: You may add <link linkend="addfacet">JBoss Web Service
+ facet to the project</link> by clicking <property>Modify...</property> button. The opened page is like <property>Figure 2.4</property>.</para>
+ </listitem>
+ <listitem>
<para>Configure Web Module values:</para>
<figure>
<title>Web Module Settings Configuration</title>
@@ -59,13 +63,25 @@
</figure>
</listitem>
</itemizedlist>
- <para>Click on the <property>Finish</property> button. Next you will need to add JBoss Web Service facet to the project:</para>
+ <para>If you added the JBoss Web Service facet to the project, now the <property>Finish</property> button is disable. You must click <property>Next</property> button to set more information about the JBoss Web Service facet. The page is like <property>Figure 2.5</property>. Then click on the <property>Finish</property> button.</para>
+ <para>If you didn't add the JBoss Web Service facet to the project, click on the <property>Finish</property> button. Next you will need to add JBoss Web Service facet to the project.</para>
</section>
<section id="addfacet">
<title>Configure JBoss Web Service facet settings</title>
- <para>If you have already created a new Dynamic Web project, the next step is to add JBoss Web
- Service facet to the project. Right-click on the project, select its <emphasis><property>Properties</property></emphasis> and then find <emphasis>Project Facets</emphasis> in the tree-view on the left-side of the project properties dialog. Tick on the check box for JBoss Web Services and open additional configuration for it, having clicked on the <emphasis><property>Further configuration required...</property></emphasis> link. In the opened window</para>
+ <para>If you have already created a new Dynamic Web project and not set the JBoss Web Service facet to the project, the next step is to add JBoss Web
+ Service facet to the project. Right-click on the project, select its <emphasis><property>Properties</property></emphasis> and then find <emphasis>Project Facets</emphasis> in the tree-view on the left-side of the project properties dialog.
+ Tick on the check box for JBoss Web Services. You will see what like this: </para>
+ <figure id="figure_addfacet_0">
+ <title>Choose JBoss Web Service Facet</title>
+ <mediaobject>
+ <imageobject>
+ <imagedata fileref="images/topdown/jbossws_facet_0.png"/>
+ </imageobject>
+ </mediaobject>
+ </figure>
+ <para>At the bottom-left of the right-side of the project properties dialog, there is a error link: <emphasis><property>Further configuration required...</property></emphasis> . You must click the link to set more information about JBoss Web Service facet.</para>
+ <para>Click on the <emphasis><property>Further configuration required...</property></emphasis> link. In the opened window</para>
<figure id="figure_addfacet">
<title>Configure JBoss Web Service Facet</title>
<mediaobject>
@@ -95,7 +111,7 @@
</mediaobject>
</figure>
<para>See how to configure a new JBossWS runtime <link linkend="preference">here</link>.</para>
-
+ <para>After setting the information about JBoss Web Service facet, for saving the result, you should click the <property>Apply</property> or <property>OK</property> button at the bottom-right of the right-side of the project properties dialog.</para>
</section>
15 years, 6 months
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java 2009-06-17 12:29:35 UTC (rev 16010)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaEditor.java 2009-06-17 12:31:47 UTC (rev 16011)
@@ -16,6 +16,7 @@
import java.io.Writer;
import java.net.MalformedURLException;
import java.net.URL;
+import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
@@ -24,6 +25,8 @@
import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Status;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.browser.ProgressEvent;
@@ -44,7 +47,6 @@
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Event;
-import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Link;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Menu;
@@ -59,6 +61,7 @@
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.browser.IWorkbenchBrowserSupport;
import org.eclipse.ui.editors.text.ILocationProvider;
+import org.eclipse.ui.internal.part.StatusPart;
import org.eclipse.ui.part.EditorPart;
import org.jboss.tools.common.model.XModelException;
import org.jboss.tools.jst.jsp.preferences.VpePreference;
@@ -78,7 +81,6 @@
import org.jboss.tools.vpe.messages.VpeUIMessages;
import org.jboss.tools.vpe.resref.VpeResourcesDialog;
import org.jboss.tools.vpe.xulrunner.XPCOM;
-import org.jboss.tools.vpe.xulrunner.XulRunnerException;
import org.jboss.tools.vpe.xulrunner.editor.XulRunnerEditor;
import org.mozilla.interfaces.nsIDOMDocument;
import org.mozilla.interfaces.nsIDOMElement;
@@ -159,6 +161,7 @@
}
public void init(IEditorSite site, IEditorInput input) throws PartInitException {
+ super.setSite(site);
super.setInput(input);
}
@@ -457,11 +460,9 @@
// }
xulRunnerEditor.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
+ } catch (Throwable t) {
+ showXulRunnerException(cmpEd, t);
}
- catch (XulRunnerException e) {
- layout.verticalSpacing = 10;
- showXulRunnerException(cmpEd, e);
- }
/*
* https://jira.jboss.org/jira/browse/JBIDE-4062
@@ -518,22 +519,38 @@
}
/**
* Logs given {@code exception} and shows error message in
* the {@code parent} composite.
*/
protected void showXulRunnerException(Composite parent,
- XulRunnerException exception) {
- VpePlugin.getPluginLog().logError(
- VpeUIMessages.MOZILLA_LOADING_ERROR_LOG_ENTRY, exception);
+ Throwable throwable) {
+ String errorMessage = MessageFormat.format(
+ VpeUIMessages.MOZILLA_LOADING_ERROR, throwable.getMessage());
- Label title = new Label(parent, SWT.WRAP);
- title.setText(VpeUIMessages.MOZILLA_LOADING_ERROR);
- title.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
+ VpePlugin.getPluginLog().logError(errorMessage, throwable);
+ parent.setLayout(new GridLayout());
+ Composite statusComposite = new Composite(parent, SWT.NONE);
+ Color bgColor= parent.getDisplay().getSystemColor(SWT.COLOR_LIST_BACKGROUND);
+ Color fgColor= parent.getDisplay().getSystemColor(SWT.COLOR_LIST_FOREGROUND);
+ parent.setBackground(bgColor);
+ parent.setForeground(fgColor);
+ GridData gridData = new GridData(SWT.FILL, SWT.FILL, true, true);
+ gridData.widthHint = 0;
+ gridData.heightHint = 0;
+ statusComposite.setLayoutData(gridData);
+
+ IStatus displayStatus = new Status(IStatus.ERROR,
+ VpePlugin.PLUGIN_ID, errorMessage, throwable);
+ new StatusPart(statusComposite, displayStatus);
+
final Link link = new Link(parent, SWT.WRAP);
+ link.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
+ link.setBackground(bgColor);
link.setText(VpeUIMessages.MOZILLA_LOADING_ERROR_LINK_TEXT);
link.setToolTipText(VpeUIMessages.MOZILLA_LOADING_ERROR_LINK);
link.setForeground(link.getDisplay().getSystemColor(SWT.COLOR_BLUE));
+
link.addMouseListener(new MouseListener() {
public void mouseDown(org.eclipse.swt.events.MouseEvent e) {
BusyIndicator.showWhile(link.getDisplay(), new Runnable() {
@@ -559,9 +576,6 @@
public void mouseUp(MouseEvent e) {
}
});
- link.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
- Label fill = new Label(parent, SWT.WRAP);
- fill.setLayoutData(new GridData(GridData.FILL_BOTH));
}
private ToolItem createToolItem(ToolBar parent, int type, String image, String disabledImage,
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/mozilla/MozillaPreview.java
@@ -518,22 +519,38 @@
}
/**
- * Logs given {@code exception} and shows error message in
+ * Logs given {@code throwable} and shows error message in
* the {@code parent} composite.
*/
===================================================================